@@ -188,6 +188,9 @@ yhat.predict <- function(model_name, data) {
 #' yhat.deploy("irisModel")
 #' }
 yhat.deploy <- function(model_name) {
+  if (length(grep("^[A-Za-z_0-9]+$", model_name))==0) {
+    stop("Model name can only contain following characters: A-Za-z_0-9")
+  }
   check.image.size()
   AUTH <- get("yhat.config")
   if (length(AUTH)==0) {
@@ -246,6 +249,9 @@ yhat.deploy <- function(model_name) {
 #' }
 #' yhat.deploy.to.file("irisModel")
 yhat.deploy.to.file <- function(model_name) {
+  if (length(grep("^[A-Za-z_0-9]+$", model_name))==0) {
+    stop("Model name can only contain following characters: A-Za-z_0-9")
+  }
   AUTH <- get("yhat.config")
   username <- AUTH[["username"]]
   f <- ".yhatdeployment.img"
